<?php
/*
Plugin Name: Page Security by Contexture Shortcodes
Plugin URI: http://www.my105e.com/wordpress-plugins/contexture-page-security-shortcodes
Description: Extends Page Security by Contexture (http://www.contextureintl.com/open-source-projects/contexture-page-security-for-wordpress/) with shortcodes
Version: 1.0.0
Author: Garry Mitchell
Author URI: http://www.my105e.com/
License: GPLv2 or later
*/

/* 
	--------------------------
	This plugin requires that Page Security by Contexture is installed and enabled.
	Check for this, and notify the user if it is not.
	--------------------------
*/

function ctpxs_plugin_required() {
    $url = network_admin_url( 'plugin-install.php?tab=search&type=term&s=Page+Security+by+Contexture&plugin-search-input=Page+Security+by+Contexture' );
    echo '
    <div class="error">
        <p>The <a href="' . $url . '">Page Security by Contexture Plugin</a> is required.</p>
    </div>
    ';
}

function check_required_plugins() {
    if ( current_user_can( 'activate_plugins' ) ) {
        include_once( ABSPATH . 'wp-admin/includes/plugin.php' );
        if ( ! is_plugin_active( 'contexture-page-security/contexture-page-security.php' ) )
            add_action( 'admin_notices', 'ctpxs_plugin_required' );
    }
}
add_action( 'plugins_loaded', 'check_required_plugins' );

/* 
	* Shows the content to users who are members of the specified groups
	* Usage: [ctxps_is_member group="Group Name"]Content here[/ctxps_is_member]
*/
function ctxps_is_member_shortcode( $atts, $content = null ) {
	
	extract ( $atts );

	global $current_user; get_currentuserinfo();
	$showcontent = false;
	
	$user_id = $current_user->ID;
	$groups = explode(',',$group);
	
	$user_groups = CTXPS_Queries::get_user_groups($user_id);
	
	foreach($groups as $group_id) {
		if (in_array($group_id, $user_groups)) {
			$showcontent = true;
		}
	}
	
	if ($showcontent == true) {
		return wpautop(do_shortcode($content));
	}
}
add_shortcode( 'ctxps_is_member', 'ctxps_is_member_shortcode');


/* 
	* Shows the content to users who are members of the specified groups, but where the membership has expired
	* Usage: [ctxps_is_member group="Group Name"]Content here[/ctxps_is_member]
*/
function ctxps_is_expired_member_shortcode( $atts, $content = null ) {
	
	extract( $atts );

	global $current_user; get_currentuserinfo();
	$showcontent = false;
	
	$user_id = $current_user->ID;
	
	$group_id = ctxps_get_group_id($group);
	if (CTXPS_Queries::check_membership($user_id, $group_id) == true) {
		$expiry = ctxps_get_group_expiry_date($group_id, $user_id);
		if (!is_null($expiry)) {
			if (strtotime($expiry) < time()) {
				$showcontent = true;
			}
		}
	}
	
	if ($showcontent == true) {
		return wpautop(do_shortcode($content));
	}
}
add_shortcode( 'ctxps_is_expired_member', 'ctxps_is_expired_member_shortcode');


/* 
	* Returns expiry date for the specified group for the current user
	* Usage: [ctxps_expiry group="Group Name"]
*/

function ctxps_expiry_shortcode( $atts, $content = null ) {

	extract ( shortcode_atts( array(
		'group' => '',
		'expired' => 'Expired',
		'none' => 'Never',
		'format' => 'Y-m-d H:i:s'
	), $atts ) );
	
	global $current_user; get_currentuserinfo();
	$user_id = $current_user->ID;
	
	$group_id = ctxps_get_group_id($group);
	$expiry = ctxps_get_group_expiry_date($group_id, $user_id);
	
	if (is_null($expiry)) {
		return $none;
	}
	if (strtotime($expiry) < time()) {
		return $expired;
	}

	
	return date($format, strtotime($expiry));
}
add_shortcode( 'ctxps_expiry', 'ctxps_expiry_shortcode');

/* 
	* Shows content only to members who are *not* part of the specified group
	* Usage: [ctxps_is_not_member group="Group Name"]Content here[/ctxps_is_not_member]
*/
function ctxps_is_not_member_shortcode ($atts, $content = null) {

	extract( $atts );

	global $current_user; get_currentuserinfo();
	$showcontent = true;
	
	$user_id = $current_user->ID;
	$groups = explode(',',$group);
	
	$user_groups = CTXPS_Queries::get_user_groups($user_id);
	
	foreach($groups as $group_id) {
		if (in_array($group_id, $user_groups)) {
			$showcontent = false;
		}
	}
	if ($showcontent == true) {
		return wpautop(do_shortcode($content));
	}
	
}
add_shortcode( 'ctxps_is_not_member', 'ctxps_is_not_member_shortcode');
	

/* 
	* Shows content only to members who are not part of the specified group but whose membership has expired
	* Usage: [ctxps_is_not_expired_member group="Group Name"]Content here[/ctxps_is_not_expired_member]
*/
function ctxps_is_not_expired_member_shortcode ($atts, $content = null) {

	extract( $atts );

	global $current_user; get_currentuserinfo();
	$showcontent = true;
	
	$user_id = $current_user->ID;
	
	$group_id = ctxps_get_group_id($group);
	if (CTXPS_Queries::check_membership($user_id, $group_id) == true) {
		$showcontent = false;
	}
	
	if ($showcontent == true) {
		return wpautop(do_shortcode($content));
	}
	
}
add_shortcode( 'ctxps_is_not_expired_member', 'ctxps_is_not_expired_member_shortcode');
	
    /**
     * Checks if a group with the provided name already exists. This is used to validate
     * in self::create_group() to ensure duplicate group names don't crop up.
     *
     * @global wpdb $wpdb
     * @global CTXPSC_Tables $ctxpsdb
     * @param string $group_name
     * @return boolean Returns true if the group already exists, false if not.
     */
    function ctxps_get_group_id($group_name){
        global $wpdb,$ctxpsdb;

        //Get rid of extra whitespace
        $group_name = trim($group_name);
        //DB column requires names < 40 char
        $group_name = substr($group_name, 0, 40);
		
        //Check for a match
        $group_id = $wpdb->get_var($wpdb->prepare(
                "SELECT `ID` FROM `".$ctxpsdb->groups."`
                    WHERE group_title = '%s'",
                $group_name
        ));
		
        return ($group_id);
		
    }	
	
	/**
	 * Based on get_group_members from Contexture Page Security
	 *
     * This gets the user's expiry date from CTXPS.
     *
     * @global wpdb $wpdb
     * @global CTXPSC_Tables $ctxpsdb
     * @param int $user_id The ID of the user to get group expiry for.
     * @return array
     */
    function ctxps_get_group_expiry_date($group_id, $user_id){
        global $wpdb,$ctxpsdb;

        return $wpdb->get_var($wpdb->prepare(
            'SELECT
                `'.$ctxpsdb->group_rels.'`.grel_expires
            FROM `'.$ctxpsdb->group_rels.'`
            JOIN `'.$wpdb->users.'`
                ON `'.$ctxpsdb->group_rels.'`.grel_user_id = `'.$wpdb->users.'`.ID
            WHERE grel_group_id = %s AND `'.$wpdb->users.'`.ID = %s',
            $group_id, $user_id
        ));
    }	
?>